==> glpi-10.0.4.tgz: glpi/public/lib/tinymce-i18n/langs6/sr.js <==
/*!
 * TinyMCE Language Pack
 *
 * Copyright (c) 2022 Ephox Corporation DBA Tiny Technologies, Inc.
 * Licensed under the Tiny commercial license. See https://www.tiny.cloud/legal/
 */
tinymce.addI18n("sr", {
    "Redo": "Napred",
    "Undo": "Nazad",
    "Cut": "Iseci",
    "Copy": "Kopiraj",
    "Paste": "Nalepi",
    "Select all": "Obele\u017ei sve",
    "New document": "Novi dokument",
    "Ok": "Ok",
    "Cancel": "Opozovi",
    "Visual aids": "Vizuelna pomagala",
    "Bold": "Podebljan",
    "Italic": "isko\u0161en",
    "Underline": "Podvu\u010den",
    "Strikethrough": "Precrtan",
    "Superscript": "Natpis",
    "Subscript": "Potpisan",
    "Clear formatting": "Brisanje formatiranja",
    "Remove": "",
    "Align left": "Poravnano levo",
    "Align center": "Poravnano centar",
    "Align right": "Poravnano  desno",
    "No alignment": "",
    "Justify": "Poravnanje",
    "Bullet list": "Lista nabrajanja",
    "Numbered list": "Numerisana lista",
    "Decrease indent": "Smanji uvla\u010denje",
    "Increase indent": "Pove\u0107aj uvla\u010denje",
    "Close": "Zatvori",
    "Formats": "Formatiraj",
    "Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.": "Va\u0161 pretra\u017eiva\u010d nepodr\u017eava direktan pristup prenosu.Koristite Ctrl+X/C/V pre\u010dice na tastaturi",
    "Headings": "Naslovi",
    "Heading 1": "Naslov 1",
    "Heading 2": "Naslov 2",
    "Heading 3": "Naslov 3",
    "Heading 4": "Naslov 4",
    "Heading 5": "Naslov 5",
    "Heading 6": "Naslov 6",
    "Preformatted": "Formatirano",
    "Div": "",
    "Pre": "",
    "Code": "Kod",
    "Paragraph": "Paragraf",
    "Blockquote": "Navodnici",
    "Inline": "U liniji",
    "Blocks": "Blokovi",
    "Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Nalepiti je sada u obi\u010dnom text modu.Sadr\u017eaj \u0107e biti nalepljen kao obi\u010dan tekst dok ne ugasite ovu opciju.",
    "Fonts": "Pisma",
    "Font sizes": "",
    "Class": "Klasa",
    "Browse for an image": "Prona\u0111i sliku",
    "OR": "ili",
    "Drop an image here": "Prevuci sliku ovde",
    "Upload": "Po\u0161alji",
    "Uploading image": "",
    "Block": "Blok",
    "Align": "Poravnaj",
    "Default": "Podrazumevano",
    "Circle": "Krug",
    "Disc": "Disk",
    "Square": "Kvadrat",
    "Lower Alpha": "Donja Alpha",
    "Lower Greek": "Ni\u017ei gr\u010dki",
    "Lower Roman": "Donji Roman",
    "Upper Alpha": "Gornji Alpha",
    "Upper Roman": "Gornji Roman",
    "Anchor...": "Sidro",
    "Anchor": "",
    "Name": "Ime",
    "ID": "",
    "ID should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "",
    "You have unsaved changes are you sure you want to navigate away?": "Imate nesa\u010duvane promene dali ste sigurni da \u017eelite da iza\u0111ete?",
    "Restore last draft": "Vrati  poslednji nacrt",
    "Special character...": "Specijalan karakter",
    "Special Character": "",
    "Source code": "Izvorni kod",
    "Insert/Edit code sample": "Dodaj/Izmeni primer koda",
    "Language": "Jezik",
    "Code sample...": "Primer koda",
    "Left to right": "Sa leve na desnu",
    "Right to left": "Sa desne na levu",
    "Title": "Naslov",
    "Fullscreen": "Pun ekran",
    "Action": "Akcija",
    "Shortcut": "Pre\u010dica",
    "Help": "Pomo\u0107",
    "Address": "Adresa",
    "Focus to menubar": "Fokus na meni",
    "Focus to toolbar": "Fokus na traku sa alatima",
    "Focus to element path": "Fokus na putanju elementa",
    "Focus to contextual toolbar": "Fokus na kontekstualnu traku alata",
    "Insert link (if link plugin activated)": "Dodaj link (ukoliko je link dodatak aktiviran)",
    "Save (if save plugin activated)": "Sa\u010duvaj (ukoliko je sa\u010duvaj dodatak aktiviran)",
    "Find (if searchreplace plugin activated)": "Prona\u0111i (ako je dodatak pretrage i zamene aktiviran)",
    "Plugins installed ({0}):": "Dodataka instalirano ({0}):",
    "Premium plugins:": "Premium dodaci",
    "Learn more...": "Saznaj vi\u0161e",
    "You are using {0}": "Koristite {0}",
    "Plugins": "Dadaci",
    "Handy Shortcuts": "Prakti\u010dne pre\u010dice",
    "Horizontal line": "Horizontalna linija",
    "Insert/edit image": "Ubaci/Promeni sliku",
    "Alternative description": "",
    "Accessibility": "",
    "Image is decorative": "",
    "Source": "Izvor",
    "Dimensions": "Dimenzije",
    "Constrain proportions": "Ograni\u010dene proporcije",
    "General": "Op\u0161te",
    "Advanced": "Napredno",
    "Style": "Stil",
    "Vertical space": "Vertikalni razmak",
    "Horizontal space": "Horizontalni razmak",
    "Border": "Okvir",
    "Insert image": "Ubaci sliku",
    "Image...": "Slika...",
    "Image list": "Lista slika",
    "Resize": "Promeni veli\u010dinu",
    "Insert date/time": "Ubaci datum/vreme",
    "Date/time": "Datum/vreme",
    "Insert/edit link": "Ubaci/promeni vezu",
    "Text to display": "Tekst za prikaz",
    "Url": "",
    "Open link in...": "Otvori vezu u...",
    "Current window": "Istom prozoru",
    "None": "Ni\u0161ta",
    "New window": "Novi prozor",
    "Open link": "",
    "Remove link": "Ukloni link",
    "Anchors": "sidro",
    "Link...": "Veza...",
    "Paste or type a link": "Nalepi ili ukucaj link",
    "The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Izgleda da je URL koji ste uneli email adresa. Da li \u017eelite da dodate zahtevani mailto: prefiks?",
    "The URL you entered seems to be an external link. Do you want to add the required http:// prefix?": "Izgleda da je URL koji ste uneli spolja\u0161nja veza. Da li \u017eelite da dodate zahtevani http:// prefiks?",
    "The URL you entered seems to be an external link. Do you want to add the required https:// prefix?": "",
    "Link list": "Lista veza",
    "Insert video": "Ubaci video",
    "Insert/edit video": "Ubaci/promeni video",
    "Insert/edit media": "Ubaci/izmeni mediju",
    "Alternative source": "Alternativni izvor",
    "Alternative source URL": "Alternativni izvorni URL",
    "Media poster (Image URL)": "Poster medije (slika URL)",
    "Paste your embed code below:": "Nalepite ugra\u0111eni kod ispod:",
    "Embed": "Ugra\u0111eno",
    "Media...": "Medija...",
    "Nonbreaking space": "bez ramaka",
    "Page break": "Lomljenje stranice",
    "Paste as text": "Nalepi kao tekst",
    "Preview": "Pregled",
    "Print": "",
    "Print...": "\u0160tampa...",
    "Save": "Sa\u010duvati",
    "Find": "Na\u0111i",
    "Replace with": "Zameni sa",
    "Replace": "Zameni",
    "Replace all": "Zameni sve",
    "Previous": "Predhodno",
    "Next": "Slede\u0107i",
    "Find and Replace": "",
    "Find and replace...": "Prona\u0111i i zameni...",
    "Could not find the specified string.": "Nije mogu\u0107e prona\u0107i navedeni niz.",
    "Match case": "Predmet za upore\u0111ivanje",
    "Find whole words only": "Prona\u0111i samo cele re\u010di",
    "Find in selection": "",
    "Insert table": "ubaci tabelu",
    "Table properties": "Postavke tabele",
    "Delete table": "Obri\u0161i tabelu",
    "Cell": "\u0106elija",
    "Row": "Red",
    "Column": "Kolona",
    "Cell properties": "Postavke \u0107elije",
    "Merge cells": "Spoji \u0107elije",
    "Split cell": "Razdvoji \u0107elije",
    "Insert row before": "Ubaci red pre",
    "Insert row after": "Ubaci red posle",
    "Delete row": "Obri\u0161i red",
    "Row properties": "Postavke reda",
    "Cut row": "Iseci red",
    "Cut column": "",
    "Copy row": "Kopiraj red",
    "Copy column": "",
    "Paste row before": "Nalepi red pre",
    "Paste column before": "",
    "Paste row after": "Nalepi red posle",
    "Paste column after": "",
    "Insert column before": "Ubaci kolonu pre",
    "Insert column after": "Ubaci kolonu posle",
    "Delete column": "Obri\u0161i kolonu",
    "Cols": "Kolone",
    "Rows": "Redovi",
    "Width": "\u0160irina",
    "Height": "Visina",
    "Cell spacing": "Prostor \u0107elije",
    "Cell padding": "Razmak \u0107elije",
    "Row clipboard actions": "",
    "Column clipboard actions": "",
    "Table styles": "",
    "Cell styles": "",
    "Column header": "",
    "Row header": "",
    "Table caption": "",
    "Caption": "Natpis",
    "Show caption": "Prika\u017ei naslov",
    "Left": "Levo",
    "Center": "Centar",
    "Right": "Desno",
    "Cell type": "Tip \u0107elije",
    "Scope": "Obim",
    "Alignment": "Svrstavanje",
    "Horizontal align": "",
    "Vertical align": "",
    "Top": "Vrh",
    "Middle": "Sredina",
    "Bottom": "Podno\u017eje",
    "Header cell": "Visina \u0107elije",
    "Row group": "Grupa reda",
    "Column group": "Grupa kolone",
    "Row type": "Tip reda",
    "Header": "Zaglavlje",
    "Body": "Telo",
    "Footer": "Podno\u017eje",
    "Border color": "Boja ivice",
    "Solid": "",
    "Dotted": "",
    "Dashed": "",
    "Double": "",
    "Groove": "",
    "Ridge": "",
    "Inset": "",
    "Outset": "",
    "Hidden": "",
    "Insert template...": "Umetni \u0161emu...",
    "Templates": "\u0160abloni",
    "Template": "\u0160ablon",
    "Insert Template": "",
    "Text color": "Boja tekst",
    "Background color": "Boja pozadine",
    "Custom...": "Posebno...",
    "Custom color": "Posebna boja",
    "No color": "Bez boje",
    "Remove color": "Ukloni boju",
    "Show blocks": "Prikaz blokova",
    "Show invisible characters": "Prika\u017ei nevidljive karaktere",
    "Word count": "Broja\u010d re\u010di",
    "Count": "Ra\u010dunati",
    "Document": "Dokument",
    "Selection": "Odabiranje",
    "Words": "Re\u010di",
    "Words: {0}": "Re\u010di:{0}",
    "{0} words": "{0} re\u010di",
    "File": "Datoteka",
    "Edit": "Ure\u0111ivanje",
    "Insert": "Umetni",
    "View": "Prikaz",
    "Format": "",
    "Table": "Tabela",
    "Tools": "Alatke",
    "Powered by {0}": "Pokre\u0107e ga {0}",
    "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Oboga\u0107en tekst. Pritisni te ALT-F9 za meni.Pritisnite ALT-F10 za traku sa alatkama.Pritisnite ALT-0 za pomo\u0107",
    "Image title": "Naslov slike",
    "Border width": "\u0160irina okvira",
    "Border style": "Stil okvira",
    "Error": "Gre\u0161ka",
    "Warn": "Upozorenje",
    "Valid": "Ispravno",
    "To open the popup, press Shift+Enter": "Da otvorite popup, pritisnite Shift+Enter",
    "Rich Text Area": "",
    "Rich Text Area. Press ALT-0 for help.": "Podru\u010dje oboga\u0107enog teksta. Pritisnite ALT-0 za pomo\u0107.",
    "System Font": "Sistemski font",
    "Failed to upload image: {0}": "",
    "Failed to load plugin: {0} from url {1}": "",
    "Failed to load plugin url: {0}": "",
    "Failed to initialize plugin: {0}": "",
    "example": "",
    "Search": "",
    "All": "",
    "Currency": "",
    "Text": "",
    "Quotations": "",
    "Mathematical": "",
    "Extended Latin": "",
    "Symbols": "",
    "Arrows": "",
    "User Defined": "",
    "dollar sign": "",
    "currency sign": "",
    "euro-currency sign": "",
    "colon sign": "",
    "cruzeiro sign": "",
    "french franc sign": "",
    "lira sign": "",
    "mill sign": "",
    "naira sign": "",
    "peseta sign": "",
    "rupee sign": "",
    "won sign": "",
    "new sheqel sign": "",
    "dong sign": "",
    "kip sign": "",
    "tugrik sign": "",
    "drachma sign": "",
    "german penny symbol": "",
    "peso sign": "",
    "guarani sign": "",
    "austral sign": "",
    "hryvnia sign": "",
    "cedi sign": "",
    "livre tournois sign": "",
    "spesmilo sign": "",
    "tenge sign": "",
    "indian rupee sign": "",
    "turkish lira sign": "",
    "nordic mark sign": "",
    "manat sign": "",
    "ruble sign": "",
    "yen character": "",
    "yuan character": "",
    "yuan character, in hong kong and taiwan": "",
    "yen/yuan character variant one": "",
    "Emojis": "",
    "Emojis...": "",
    "Loading emojis...": "",
    "Could not load emojis": "",
    "People": "",
    "Animals and Nature": "",
    "Food and Drink": "",
    "Activity": "",
    "Travel and Places": "",
    "Objects": "",
    "Flags": "",
    "Characters": "",
    "Characters (no spaces)": "",
    "{0} characters": "",
    "Error: Form submit field collision.": "",
    "Error: No form element found.": "",
    "Color swatch": "",
    "Color Picker": "Odabir boje",
    "Invalid hex color code: {0}": "",
    "Invalid input": "",
    "R": "",
    "Red component": "",
    "G": "",
    "Green component": "",
    "B": "",
    "Blue component": "",
    "#": "",
    "Hex color code": "",
    "Range 0 to 255": "",
    "Turquoise": "",
    "Green": "",
    "Blue": "",
    "Purple": "",
    "Navy Blue": "",
    "Dark Turquoise": "",
    "Dark Green": "",
    "Medium Blue": "",
    "Medium Purple": "",
    "Midnight Blue": "",
    "Yellow": "",
    "Orange": "",
    "Red": "",
    "Light Gray": "",
    "Gray": "",
    "Dark Yellow": "",
    "Dark Orange": "",
    "Dark Red": "",
    "Medium Gray": "",
    "Dark Gray": "",
    "Light Green": "",
    "Light Yellow": "",
    "Light Red": "",
    "Light Purple": "",
    "Light Blue": "",
    "Dark Purple": "",
    "Dark Blue": "",
    "Black": "",
    "White": "",
    "Switch to or from fullscreen mode": "",
    "Open help dialog": "",
    "history": "",
    "styles": "",
    "formatting": "",
    "alignment": "",
    "indentation": "",
    "Font": "",
    "Size": "",
    "More...": "",
    "Select...": "",
    "Preferences": "",
    "Yes": "",
    "No": "",
    "Keyboard Navigation": "",
    "Version": "",
    "Code view": "",
    "Open popup menu for split buttons": "",
    "List Properties": "",
    "List properties...": "",
    "Start list at number": "",
    "Line height": "",
    "Dropped file type is not supported": "",
    "Loading...": "",
    "ImageProxy HTTP error: Rejected request": "",
    "ImageProxy HTTP error: Could not find Image Proxy": "",
    "ImageProxy HTTP error: Incorrect Image Proxy URL": "",
    "ImageProxy HTTP error: Unknown ImageProxy error": ""
});

==> glpi-10.0.7.tgz: glpi/public/lib/tinymce-i18n/langs6/sr.js <==
/*!
 * TinyMCE Language Pack
 *
 * Copyright (c) 2022 Ephox Corporation DBA Tiny Technologies, Inc.
 * Licensed under the Tiny commercial license. See https://www.tiny.cloud/legal/
 */
tinymce.addI18n('sr', {
    "Redo": "Napred",
    "Undo": "Nazad",
    "Cut": "Iseci",
    "Copy": "Kopiraj",
    "Paste": "Nalepi",
    "Select all": "Obeleži sve",
    "New document": "Novi dokument",
    "Ok": "Ok",
    "Cancel": "Opozovi",
    "Visual aids": "Vizuelna pomagala",
    "Bold": "Podebljan",
    "Italic": "iskošen",
    "Underline": "Podvučen",
    "Strikethrough": "Precrtan",
    "Superscript": "Natpis",
    "Subscript": "Potpisan",
    "Clear formatting": "Brisanje formatiranja",
    "Remove": "",
    "Align left": "Poravnano levo",
    "Align center": "Poravnano centar",
    "Align right": "Poravnano  desno",
    "No alignment": "",
    "Justify": "Poravnanje",
    "Bullet list": "Lista nabrajanja",
    "Numbered list": "Numerisana lista",
    "Decrease indent": "Smanji uvlačenje",
    "Increase indent": "Povećaj uvlačenje",
    "Close": "Zatvori",
    "Formats": "Formatiraj",
    "Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.": "Vaš pretraživač nepodržava direktan pristup prenosu.Koristite Ctrl+X/C/V prečice na tastaturi",
    "Headings": "Naslovi",
    "Heading 1": "Naslov 1",
    "Heading 2": "Naslov 2",
    "Heading 3": "Naslov 3",
    "Heading 4": "Naslov 4",
    "Heading 5": "Naslov 5",
    "Heading 6": "Naslov 6",
    "Preformatted": "Formatirano",
    "Div": "",
    "Pre": "",
    "Code": "Kod",
    "Paragraph": "Paragraf",
    "Blockquote": "Navodnici",
    "Inline": "U liniji",
    "Blocks": "Blokovi",
    "Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Nalepiti je sada u običnom text modu.Sadržaj će biti nalepljen kao običan tekst dok ne ugasite ovu opciju.",
    "Fonts": "Pisma",
    "Font sizes": "",
    "Class": "Klasa",
    "Browse for an image": "Pronađi sliku",
    "OR": "ili",
    "Drop an image here": "Prevuci sliku ovde",
    "Upload": "Pošalji",
    "Uploading image": "",
    "Block": "Blok",
    "Align": "Poravnaj",
    "Default": "Podrazumevano",
    "Circle": "Krug",
    "Disc": "Disk",
    "Square": "Kvadrat",
    "Lower Alpha": "Donja Alpha",
    "Lower Greek": "Niži grčki",
    "Lower Roman": "Donji Roman",
    "Upper Alpha": "Gornji Alpha",
    "Upper Roman": "Gornji Roman",
    "Anchor...": "Sidro",
    "Anchor": "",
    "Name": "Ime",
    "ID": "",
    "ID should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "",
    "You have unsaved changes are you sure you want to navigate away?": "Imate nesačuvane promene dali ste sigurni da želite da izađete?",
    "Restore last draft": "Vrati  poslednji nacrt",
    "Special character...": "Specijalan karakter",
    "Special Character": "",
    "Source code": "Izvorni kod",
    "Insert/Edit code sample": "Dodaj/Izmeni primer koda",
    "Language": "Jezik",
    "Code sample...": "Primer koda",
    "Left to right": "Sa leve na desnu",
    "Right to left": "Sa desne na levu",
    "Title": "Naslov",
    "Fullscreen": "Pun ekran",
    "Action": "Akcija",
    "Shortcut": "Prečica",
    "Help": "Pomoć",
    "Address": "Adresa",
    "Focus to menubar": "Fokus na meni",
    "Focus to toolbar": "Fokus na traku sa alatima",
    "Focus to element path": "Fokus na putanju elementa",
    "Focus to contextual toolbar": "Fokus na kontekstualnu traku alata",
    "Insert link (if link plugin activated)": "Dodaj link (ukoliko je link dodatak aktiviran)",
    "Save (if save plugin activated)": "Sačuvaj (ukoliko je sačuvaj dodatak aktiviran)",
    "Find (if searchreplace plugin activated)": "Pronađi (ako je dodatak pretrage i zamene aktiviran)",
    "Plugins installed ({0}):": "Dodataka instalirano ({0}):",
    "Premium plugins:": "Premium dodaci",
    "Learn more...": "Saznaj više",
    "You are using {0}": "Koristite {0}",
    "Plugins": "Dadaci",
    "Handy Shortcuts": "Praktične prečice",
    "Horizontal line": "Horizontalna linija",
    "Insert/edit image": "Ubaci/Promeni sliku",
    "Alternative description": "",
    "Accessibility": "",
    "Image is decorative": "",
    "Source": "Izvor",
    "Dimensions": "Dimenzije",
    "Constrain proportions": "Ograničene proporcije",
    "General": "Opšte",
    "Advanced": "Napredno",
    "Style": "Stil",
    "Vertical space": "Vertikalni razmak",
    "Horizontal space": "Horizontalni razmak",
    "Border": "Okvir",
    "Insert image": "Ubaci sliku",
    "Image...": "Slika...",
    "Image list": "Lista slika",
    "Resize": "Promeni veličinu",
    "Insert date/time": "Ubaci datum/vreme",
    "Date/time": "Datum/vreme",
    "Insert/edit link": "Ubaci/promeni vezu",
    "Text to display": "Tekst za prikaz",
    "Url": "",
    "Open link in...": "Otvori vezu u...",
    "Current window": "Istom prozoru",
    "None": "Ništa",
    "New window": "Novi prozor",
    "Open link": "",
    "Remove link": "Ukloni link",
    "Anchors": "sidro",
    "Link...": "Veza...",
    "Paste or type a link": "Nalepi ili ukucaj link",
    "The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Izgleda da je URL koji ste uneli email adresa. Da li želite da dodate zahtevani mailto: prefiks?",
    "The URL you entered seems to be an external link. Do you want to add the required http:// prefix?": "Izgleda da je URL koji ste uneli spoljašnja veza. Da li želite da dodate zahtevani http:// prefiks?",
    "The URL you entered seems to be an external link. Do you want to add the required https:// prefix?": "",
    "Link list": "Lista veza",
    "Insert video": "Ubaci video",
    "Insert/edit video": "Ubaci/promeni video",
    "Insert/edit media": "Ubaci/izmeni mediju",
    "Alternative source": "Alternativni izvor",
    "Alternative source URL": "Alternativni izvorni URL",
    "Media poster (Image URL)": "Poster medije (slika URL)",
    "Paste your embed code below:": "Nalepite ugrađeni kod ispod:",
    "Embed": "Ugrađeno",
    "Media...": "Medija...",
    "Nonbreaking space": "bez ramaka",
    "Page break": "Lomljenje stranice",
    "Paste as text": "Nalepi kao tekst",
    "Preview": "Pregled",
    "Print": "",
    "Print...": "Štampa...",
    "Save": "Sačuvati",
    "Find": "Nađi",
    "Replace with": "Zameni sa",
    "Replace": "Zameni",
    "Replace all": "Zameni sve",
    "Previous": "Predhodno",
    "Next": "Sledeći",
    "Find and Replace": "",
    "Find and replace...": "Pronađi i zameni...",
    "Could not find the specified string.": "Nije moguće pronaći navedeni niz.",
    "Match case": "Predmet za upoređivanje",
    "Find whole words only": "Pronađi samo cele reči",
    "Find in selection": "",
    "Insert table": "ubaci tabelu",
    "Table properties": "Postavke tabele",
    "Delete table": "Obriši tabelu",
    "Cell": "Ćelija",
    "Row": "Red",
    "Column": "Kolona",
    "Cell properties": "Postavke ćelije",
    "Merge cells": "Spoji ćelije",
    "Split cell": "Razdvoji ćelije",
    "Insert row before": "Ubaci red pre",
    "Insert row after": "Ubaci red posle",
    "Delete row": "Obriši red",
    "Row properties": "Postavke reda",
    "Cut row": "Iseci red",
    "Cut column": "",
    "Copy row": "Kopiraj red",
    "Copy column": "",
    "Paste row before": "Nalepi red pre",
    "Paste column before": "",
    "Paste row after": "Nalepi red posle",
    "Paste column after": "",
    "Insert column before": "Ubaci kolonu pre",
    "Insert column after": "Ubaci kolonu posle",
    "Delete column": "Obriši kolonu",
    "Cols": "Kolone",
    "Rows": "Redovi",
    "Width": "Širina",
    "Height": "Visina",
    "Cell spacing": "Prostor ćelije",
    "Cell padding": "Razmak ćelije",
    "Row clipboard actions": "",
    "Column clipboard actions": "",
    "Table styles": "",
    "Cell styles": "",
    "Column header": "",
    "Row header": "",
    "Table caption": "",
    "Caption": "Natpis",
    "Show caption": "Prikaži naslov",
    "Left": "Levo",
    "Center": "Centar",
    "Right": "Desno",
    "Cell type": "Tip ćelije",
    "Scope": "Obim",
    "Alignment": "Svrstavanje",
    "Horizontal align": "",
    "Vertical align": "",
    "Top": "Vrh",
    "Middle": "Sredina",
    "Bottom": "Podnožje",
    "Header cell": "Visina ćelije",
    "Row group": "Grupa reda",
    "Column group": "Grupa kolone",
    "Row type": "Tip reda",
    "Header": "Zaglavlje",
    "Body": "Telo",
    "Footer": "Podnožje",
    "Border color": "Boja ivice",
    "Solid": "",
    "Dotted": "",
    "Dashed": "",
    "Double": "",
    "Groove": "",
    "Ridge": "",
    "Inset": "",
    "Outset": "",
    "Hidden": "",
    "Insert template...": "Umetni šemu...",
    "Templates": "Šabloni",
    "Template": "Šablon",
    "Insert Template": "",
    "Text color": "Boja tekst",
    "Background color": "Boja pozadine",
    "Custom...": "Posebno...",
    "Custom color": "Posebna boja",
    "No color": "Bez boje",
    "Remove color": "Ukloni boju",
    "Show blocks": "Prikaz blokova",
    "Show invisible characters": "Prikaži nevidljive karaktere",
    "Word count": "Brojač reči",
    "Count": "Računati",
    "Document": "Dokument",
    "Selection": "Odabiranje",
    "Words": "Reči",
    "Words: {0}": "Reči:{0}",
    "{0} words": "{0} reči",
    "File": "Datoteka",
    "Edit": "Uređivanje",
    "Insert": "Umetni",
    "View": "Prikaz",
    "Format": "",
    "Table": "Tabela",
    "Tools": "Alatke",
    "Powered by {0}": "Pokreće ga {0}",
    "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Obogaćen tekst. Pritisni te ALT-F9 za meni.Pritisnite ALT-F10 za traku sa alatkama.Pritisnite ALT-0 za pomoć",
    "Image title": "Naslov slike",
    "Border width": "Širina okvira",
    "Border style": "Stil okvira",
    "Error": "Greška",
    "Warn": "Upozorenje",
    "Valid": "Ispravno",
    "To open the popup, press Shift+Enter": "Da otvorite popup, pritisnite Shift+Enter",
    "Rich Text Area": "",
    "Rich Text Area. Press ALT-0 for help.": "Područje obogaćenog teksta. Pritisnite ALT-0 za pomoć.",
    "System Font": "Sistemski font",
    "Failed to upload image: {0}": "",
    "Failed to load plugin: {0} from url {1}": "",
    "Failed to load plugin url: {0}": "",
    "Failed to initialize plugin: {0}": "",
    "example": "",
    "Search": "",
    "All": "",
    "Currency": "",
    "Text": "",
    "Quotations": "",
    "Mathematical": "",
    "Extended Latin": "",
    "Symbols": "",
    "Arrows": "",
    "User Defined": "",
    "dollar sign": "",
    "currency sign": "",
    "euro-currency sign": "",
    "colon sign": "",
    "cruzeiro sign": "",
    "french franc sign": "",
    "lira sign": "",
    "mill sign": "",
    "naira sign": "",
    "peseta sign": "",
    "rupee sign": "",
    "won sign": "",
    "new sheqel sign": "",
    "dong sign": "",
    "kip sign": "",
    "tugrik sign": "",
    "drachma sign": "",
    "german penny symbol": "",
    "peso sign": "",
    "guarani sign": "",
    "austral sign": "",
    "hryvnia sign": "",
    "cedi sign": "",
    "livre tournois sign": "",
    "spesmilo sign": "",
    "tenge sign": "",
    "indian rupee sign": "",
    "turkish lira sign": "",
    "nordic mark sign": "",
    "manat sign": "",
    "ruble sign": "",
    "yen character": "",
    "yuan character": "",
    "yuan character, in hong kong and taiwan": "",
    "yen/yuan character variant one": "",
    "Emojis": "",
    "Emojis...": "",
    "Loading emojis...": "",
    "Could not load emojis": "",
    "People": "",
    "Animals and Nature": "",
    "Food and Drink": "",
    "Activity": "",
    "Travel and Places": "",
    "Objects": "",
    "Flags": "",
    "Characters": "",
    "Characters (no spaces)": "",
    "{0} characters": "",
    "Error: Form submit field collision.": "",
    "Error: No form element found.": "",
    "Color swatch": "",
    "Color Picker": "Odabir boje",
    "Invalid hex color code: {0}": "",
    "Invalid input": "",
    "R": "",
    "Red component": "",
    "G": "",
    "Green component": "",
    "B": "",
    "Blue component": "",
    "#": "",
    "Hex color code": "",
    "Range 0 to 255": "",
    "Turquoise": "",
    "Green": "",
    "Blue": "",
    "Purple": "",
    "Navy Blue": "",
    "Dark Turquoise": "",
    "Dark Green": "",
    "Medium Blue": "",
    "Medium Purple": "",
    "Midnight Blue": "",
    "Yellow": "",
    "Orange": "",
    "Red": "",
    "Light Gray": "",
    "Gray": "",
    "Dark Yellow": "",
    "Dark Orange": "",
    "Dark Red": "",
    "Medium Gray": "",
    "Dark Gray": "",
    "Light Green": "",
    "Light Yellow": "",
    "Light Red": "",
    "Light Purple": "",
    "Light Blue": "",
    "Dark Purple": "",
    "Dark Blue": "",
    "Black": "",
    "White": "",
    "Switch to or from fullscreen mode": "",
    "Open help dialog": "",
    "history": "",
    "styles": "",
    "formatting": "",
    "alignment": "",
    "indentation": "",
    "Font": "",
    "Size": "",
    "More...": "",
    "Select...": "",
    "Preferences": "",
    "Yes": "",
    "No": "",
    "Keyboard Navigation": "",
    "Version": "",
    "Code view": "",
    "Open popup menu for split buttons": "",
    "List Properties": "",
    "List properties...": "",
    "Start list at number": "",
    "Line height": "",
    "Dropped file type is not supported": "",
    "Loading...": "",
    "ImageProxy HTTP error: Rejected request": "",
    "ImageProxy HTTP error: Could not find Image Proxy": "",
    "ImageProxy HTTP error: Incorrect Image Proxy URL": "",
    "ImageProxy HTTP error: Unknown ImageProxy error": ""
});
